==> kibana-7.6.2p0.tgz: kibana/src/legacy/core_plugins/elasticsearch/lib/handle_es_error.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handleESError = handleESError;

var _boom = _interopRequireDefault(require("boom"));

var _lodash = _interopRequireDefault(require("lodash"));

var _elasticsearch = require("elasticsearch");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
function handleESError(error) {
  if (!(error instanceof Error)) {
    throw new Error('Expected an instance of Error');
  }

  if (error instanceof _elasticsearch.errors.ConnectionFault || error instanceof _elasticsearch.errors.ServiceUnavailable || error instanceof _elasticsearch.errors.NoConnections || error instanceof _elasticsearch.errors.RequestTimeout) {
    return _boom.default.serverUnavailable(error);
  } else if (error instanceof _elasticsearch.errors.Conflict || _lodash.default.contains(error.message, 'index_template_already_exists')) {
    return _boom.default.conflict(error);
  } else if (error instanceof _elasticsearch.errors[403]) {
    return _boom.default.forbidden(error);
  } else if (error instanceof _elasticsearch.errors.NotFound) {
    return _boom.default.notFound(error);
  } else if (error instanceof _elasticsearch.errors.BadRequest) {
    return _boom.default.badRequest(error);
  } else {
    return error;
  }
}

==> kibana-7.9.1.tgz: kibana/src/legacy/core_plugins/elasticsearch/lib/handle_es_error.js <==
"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.handleESError = handleESError;

var _boom = _interopRequireDefault(require("boom"));

var _lodash = _interopRequireDefault(require("lodash"));

var _elasticsearch = require("elasticsearch");

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

/*
 * Licensed to Elasticsearch B.V. under one or more contributor
 * license agreements. See the NOTICE file distributed with
 * this work for additional information regarding copyright
 * ownership. Elasticsearch B.V. licenses this file to you under
 * the Apache License, Version 2.0 (the "License"); you may
 * not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *    http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied.  See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */
function handleESError(error) {
  if (!(error instanceof Error)) {
    throw new Error('Expected an instance of Error');
  }

  if (error instanceof _elasticsearch.errors.ConnectionFault || error instanceof _elasticsearch.errors.ServiceUnavailable || error instanceof _elasticsearch.errors.NoConnections || error instanceof _elasticsearch.errors.RequestTimeout) {
    return _boom.default.serverUnavailable(error);
  } else if (error instanceof _elasticsearch.errors.Conflict || _lodash.default.includes(error.message, 'index_template_already_exists')) {
    return _boom.default.conflict(error);
  } else if (error instanceof _elasticsearch.errors[403]) {
    return _boom.default.forbidden(error);
  } else if (error instanceof _elasticsearch.errors.NotFound) {
    return _boom.default.notFound(error);
  } else if (error instanceof _elasticsearch.errors.BadRequest) {
    return _boom.default.badRequest(error);
  } else {
    return error;
  }
}
